@@ -41,8 +41,7 @@ test_that("textmodel_lss has all the attributes", {
     expect_equal(
         names(lss_test),
         c("data", "beta", "k", "slice", "frequency", "terms", "seeds", "seeds_weighted",
-          "embedding", "similarity", "importance",
-          "concatenator", "dummy", "call")
+          "embedding", "similarity", "concatenator", "call", "version")
     )
 
     expect_true(is.numeric(lss_test$beta))
@@ -55,8 +54,7 @@ test_that("textmodel_lss has all the attributes", {
     expect_equal(
         names(lss_test_fcm),
         c("data", "beta", "k", "slice", "frequency", "terms", "seeds", "seeds_weighted",
-          "embedding", "similarity", "importance",
-          "concatenator", "dummy", "call")
+          "embedding", "similarity", "concatenator", "call", "version")
     )
 
     expect_true(is.numeric(lss_test_fcm$beta))
@@ -69,8 +67,7 @@ test_that("textmodel_lss has all the attributes", {
     expect_equal(
         names(lss_test_nd),
         c("data", "beta", "k", "slice", "frequency", "terms", "seeds", "seeds_weighted",
-          "embedding", "similarity", "importance",
-          "concatenator", "dummy", "call")
+          "embedding", "similarity", "concatenator", "call", "version")
     )
 
 })
